<?php
/************************************************************************
 * MXChange v0.2.1                                    Start: 10/14/2003 *
 * ===============                              Last change: 04/28/2004 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : what-login.php                                   *
 * -------------------------------------------------------------------- *
 * Short description : Login area (redirects to the real login module)  *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Loginbereich (leitet an das richtige Lgin-Modul  *
 *                     weiter)                                          *
 * -------------------------------------------------------------------- *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2008 by Roland Haeder                           *
 * For more information visit: http://www.mxchange.org                  *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	$INC = substr(dirname(__FILE__), 0, strpos(dirname(__FILE__), "/inc") + 4) . "/security.php";
	require($INC);
} elseif ((!EXT_IS_ACTIVE("user")) && (!IS_ADMIN())) {
	addFatalMessage(getMessage('EXTENSION_PROBLEM_EXT_INACTIVE'), "user");
	return;
}

// Add description as navigation point
ADD_DESCR("guest", __FILE__);

global $DATA, $ERROR;

// Initialize variables
$ERROR = 0;
$probe_nickname = false;
$uid = false;
$hash = "";
$URL = "";
$ADD = "";

// Already logged in?
if ((!empty($GLOBALS['userid'])) && (isSessionVariableSet('u_hash'))) {
	// Maybe, then continue with it
	$uid = $GLOBALS['userid'];
} elseif ((REQUEST_ISSET_POST(('id'))) && (REQUEST_ISSET_POST(('password'))) && (IS_FORM_SENT())) {
	// Set userid and crypt password when login data was submitted
	if ((EXT_IS_ACTIVE("nickname")) && (NICKNAME_PROBE_ON_USERID(REQUEST_POST('id')))) {
		// Nickname entered
		$uid = SQL_ESCAPE(REQUEST_POST('id'));
	} else {
		// Direct userid entered
		$uid  = bigintval(REQUEST_POST('id'));
	}
} elseif (REQUEST_ISSET_POST(('new_pass'))) {
	// New password requested
	$uid = 0;
	if (REQUEST_ISSET_POST(('id'))) $uid = REQUEST_POST('id');
} else {
	// Not logged in
	$uid = 0; $hash = "";
}

// Set unset variables
if (!REQUEST_ISSET_POST(('new_pass'))) REQUEST_SET_POST('new_pass', "");
if (!REQUEST_ISSET_GET(('login')))     REQUEST_SET_GET('login'    , "");

if (IS_MEMBER()) {
	// Login immidiately...
	$URL = "modules.php?module=login";
} elseif ((IS_FORM_SENT()) && ("".$uid."" != "".REQUEST_POST('id')."")) {
	// Invalid input (no nickname extension installed but nickname entered)
	$ERROR = constant('CODE_EXTENSION_PROBLEM');
} elseif (IS_FORM_SENT()) {
	// Try the login (see inc/libs/user_functions.php)
	$URL = USER_DO_LOGIN(REQUEST_POST('id'), REQUEST_POST('password'));
} elseif ((REQUEST_ISSET_POST(('new_pass'))) && (isset($uid))) {
	// Try the userid/email lookup (see inc/libs/user_functions.php)
	$ERROR = USER_DO_NEW_PASSWORD(REQUEST_POST('email'), $uid);
}

// Login problems?
if (REQUEST_ISSET_GET(('login'))) {
	// Use code from URL
	$ERROR = SQL_ESCAPE(REQUEST_GET('login'));
} // END  - if

// Login problems?
if (!empty($ERROR)) {
	// Ok, which one now?
	$MSG = "<tr>
  <td width=\"10\" class=\"seperator\">&nbsp;</td>
  <td colspan=\"7\" align=\"center\">
    <span class=\"guest_failed\">";

	switch ($ERROR) {
		case constant('CODE_WRONG_PASS'):
			$MSG .= getMessage('LOGIN_WRONG_PASS');
			break;

		case constant('CODE_WRONG_ID'):
			$MSG .= getMessage('LOGIN_WRONG_ID');
			break;

		case constant('CODE_ID_LOCKED'):
			$MSG .= getMessage('LOGIN_ID_LOCKED');
			break;

		case constant('CODE_ID_UNCONFIRMED'):
			$MSG .= getMessage('LOGIN_ID_UNCONFIRMED');
			break;

		case constant('CODE_NO_COOKIES'):
			$MSG .= getMessage('LOGIN_NO_COOKIES');
			break;

		case constant('CODE_EXTENSION_PROBLEM'):
			if (IS_ADMIN()) {
				$MSG .= sprintf(getMessage('EXTENSION_PROBLEM_NOT_INSTALLED'), "nickname");
			} else {
				$MSG .= getMessage('LOGIN_WRONG_ID');
			}
			break;

		default:
			DEBUG_LOG(__FILE__, __LINE__, sprintf("Unhandled error code %s detected.", $ERROR));
			$MSG .= getMessage('LOGIN_WRONG_ID');
			break;
		}
		$MSG .= "</span>
  </td>
  <td width=\"10\" class=\"seperator\">&nbsp;</td>
</tr>\n";
		define('LOGIN_FAILURE_MSG', $MSG);
} else {
	// No problems, no output
	define('LOGIN_FAILURE_MSG', "");
}

// Display login form with resend-password form
if (EXT_IS_ACTIVE("nickname")) {
	LOAD_TEMPLATE("guest_nickname_login");
} else {
	LOAD_TEMPLATE("guest_login");
}

// Was an URL constructed?
if (!empty($URL)) {
	// URL was constructed
	if (getTotalFatalErrors()) {
		// Fatal errors!
		LOAD_INC_ONCE("inc/fatal_errors.php");
	} else {
		// Load URL
		LOAD_URL($URL);
	}
} // END - if

//
?>
